# Routing

[Next.js App Router](https://nextjs.org/docs/app) is used for routing in React applications. It is the standard routing solution in Next.js and keeps your UI in sync with the URL.

### Getting Started

Import [setup](setup/) project into your workspace. Setup project contains the initial template you should start working on.
You can find the completed version of this project in [solution](solution/) folder.

Before starting, run `npm i`, which will download the router packages defined in `package.json`.

### Creating different pages

The Next.js App Router introduces a new model for building applications using React's latest features such as Server Components, Streaming with Suspense, and Server Actions.

```
app
├── about
│   └── page.tsx
├── Contact
│   └── page.tsx
├── product
│   └── detail
│       └── [slug]
│           └── page.tsx
└── NotFound.tsx
```

#### How to use App router

The example above shows how to navigate to the /contact page using the <Link> component in Next.js App Router.

```
<Link href="/contact">
   Contact
</Link>
```


#### About/index.tsx

Add the following content to `About` page

```
import React from 'react'

import Heading from '@/components/Heading'

type Props = {}

const page = (props: Props) => {
  return (
    <Heading title='About' />
  )
}

export default page
```

#### Contact/index.tsx

Add the following content to `Contact` page

```
import React from 'react'
import Heading from '@/components/Heading'

type Props = {}

const page = (props: Props) => {
  return (
    <Heading title='Contact' />
  )
}

export default page
```

#### product/detail/[slug]/page.tsx

A Dynamic Segment can be created by wrapping a folder's name in square brackets: [folderName]. For example, [id] or [slug].

```
import React from "react";
import styles from "@/style/detail.module.css"
import Image from "next/image";

type Props = {
  params: { slug: string };
  searchParams: Record<string, string>;
};

const Page = async ({ params, searchParams }: Props) => {
  const { slug } = await params;
  const { image, alt, name, price, description } = await searchParams;

  return (
    <div className={styles.container}>
      <div className={styles.card}>
        {image && <Image
          src={image}
          alt={alt}
          width={50}
          height={50}
          priority
          unoptimized />}
        <h1>{name}</h1>
        <p>Ürün Kodu: {slug}</p>
        <p className={styles.price}>{price} TL</p>
        <p>{description}</p>
      </div>
    </div>
  );
};

export default Page;

```

#### NotFound.tsx

* Finally, create a `NotFound` page, which is among routes and will be navigated by the paths other than the defined ones.

```
import Link from 'next/link'
 
export default function NotFound() {
  return (
    <div>
      <h2>Not Found</h2>
      <p>Could not find requested resource</p>
      <Link href="/">Return Home</Link>
    </div>
  )
}
```

With Next.js App Router, there's no need to install any additional routing package.

